***********************************************************************************

* Set directory

cd "D:\Dropbox\Depression - Deposit Insurance\@JMCB accept"

set more off, perm
clear

use "D:\Dropbox\Depression - Deposit Insurance\@JMCB accept\JMCB_ARY2022.dta", clear

* squared ratios to see non-linear effect
gen ExcResvDepRatioSqrd=ExcResvDepositRatio^2
gen EquityRatioSqrd=EquityRatio^2
gen CollaLoanRatioSqrd = CollaLoanRatio^2


/*Creating lagged Control Variables*/
foreach varname in EquityRatio CollaLoanRatio ExcResvDepositRatio lnAsset ///
ExcResvDepRatioSqrd EquityRatioSqrd CollaLoanRatioSqrd{
by bankid: gen lag`varname'=`varname'[_n-1] 
} 

* stack the data
g di=(year>1933)
qui su bankid
expand 2
g ind=(_n>r(N))
egen id=group(ind bankid)
tsset id date, q

gen PreUnpreGrowth=GrowthLnPreDeposit
replace PreUnpreGrowth=GrowthLnUnpreDeposit if ind==1

qui su PreUnpreGrowth,de
gen DIDok = inrange(GrowthLnPreDeposit, `r(p1)', `r(p99)')

foreach x in lagEquityRatio lagCollaLoanRatio lagExcResvDepositRatio ///
laglnAsset lagEquityRatioSqrd lagCollaLoanRatioSqrd lagExcResvDepRatioSqrd {
	g UP`x'=(ind==1)*`x'
	g After`x'=di*`x'
	g UPAfter`x'=ind*di*`x'
}


* create time indexes
*xi i.date*ind, noomit
xi i.date*ind, noomit
capture drop _Idi_?

set more off, perm

g ind_di = ind*di

*******************************
* Table 1: Summary Statistics *
*******************************

* since we are expanding the dataset, we have to include ind==1
/*
1. prefereed deposit growth
2. regular deposit growth
3. preferred deposits/total deposits
4. cash-deposit ratio
5. capital-deposit ratio
6. collaterized loan/total loans
7. Ln(total assets)
*/

sum GrowthLnPreDeposit GrowthLnUnpreDeposit PreShare ExcResvDepositRatio EquityRatio CollaLoanRatio lnTotalAsset if year<1933 & DIDok & ind==1

sum GrowthLnPreDeposit GrowthLnUnpreDeposit PreShare ExcResvDepositRatio EquityRatio CollaLoanRatio lnTotalAsset if year>1933 & DIDok & ind==1


****************************************************************************************
* Table 2: Depositors reactions to banks balance-sheet characteristics, 1929 to 1938 * 
****************************************************************************************
// excess reserve ratio, capital ratio, unsecured to all loans(as control)
* column (1) all banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio   ///
if DIDok&bank_age>5 & year>1928 , cl(id) 
outreg2 *ExcResvDepositRatio *EquityRatio *CollaLoanRatio using Table2.xls, nocons bde(2)

* column (2) all banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 , cl(id) 
outreg2 *ExcResvDepositRatio *EquityRatio *CollaLoanRatio using Table2.xls, nocons bde(2) append

* column (3) all banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio   ///
if DIDok&bank_age>5 & year>1928  , cl(id) fe 
outreg2 *ExcResvDepositRatio *EquityRatio *CollaLoanRatio using Table2.xls, nocons bde(2) append

* column (4) all banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928  , cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio *CollaLoanRatio using Table2.xls, nocons bde(2) append

// NYC banks vs country vs all banks. 
// NYC + country(non nyc+ non albany,buffalo)  <  all banks
// excess reserve ratio, capital ratio, unsecured to all loans(as control)

* column (5) NYC banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & ny_flag & year>1928 , cl(id) 
outreg2 *ExcResvDepositRatio *EquityRatio *CollaLoanRatio using Table2.xls, nocons bde(2) append

* column (6) country banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio  *lagCollaLoanRatio ///
if DIDok&bank_age>5 & small_town & year>1928  , cl(id)  
outreg2 *ExcResvDepositRatio *EquityRatio *CollaLoanRatio using Table2.xls, nocons bde(2) append

* column (7) NYC banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & ny_flag , cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio *CollaLoanRatio using Table2.xls, nocons bde(2) append

* column (8) country banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio  *lagCollaLoanRatio ///
if DIDok&bank_age>5 & year>1928 & small_town, cl(id) fe 
outreg2 *ExcResvDepositRatio *EquityRatio *CollaLoanRatio using Table2.xls, nocons bde(2) append

***************************************************************************************************
* Table 3: Depositors non-linear reactions to information about excess reserves in New York City *
***************************************************************************************************

// excess reserve ratio, capital ratio, unsecured to all loans(as control) plus squared terms

* column (1) without fixed effects
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio *lagExcResvDepRatioSqrd *lagEquityRatioSqrd *lagCollaLoanRatioSqrd ///
if DIDok&bank_age>5 & ny_flag  & year>1928 , cl(id) 
outreg2 *ExcResvDepositRatio *EquityRatio *CollaLoanRatio *ExcResvDepRatioSqrd *EquityRatioSqrd *CollaLoanRatioSqrd ///
using Table3.xls, nocons bde(2) 

* column (2) with fixed effects
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio *lagExcResvDepRatioSqrd *lagEquityRatioSqrd *lagCollaLoanRatioSqrd ///
if DIDok&bank_age>5 & ny_flag  & year>1928 , cl(id) fe
outreg2 *ExcResvDepositRatio *EquityRatio *CollaLoanRatio *ExcResvDepRatioSqrd *EquityRatioSqrd *CollaLoanRatioSqrd ///
using Table3.xls, nocons bde(2) append

***********************************************************************************************************************************
* Table 4:  Depositors reactions differentiated by Fed membership, network location, securities affiliates, and foreign exposure *
***********************************************************************************************************************************

// FED member vs non-member 
// excess reserve ratio, capital ratio, unsecured to all loans(as control)

* column (1) fed member without fixed effects
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio  *lagCollaLoanRatio ///
if DIDok&bank_age>5 & year>1928 & fed, cl(id) 
outreg2 *ExcResvDepositRatio *EquityRatio using Table4.xls, nocons bde(2)

* column (2) non-member without fixed effects
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & !fed, cl(id) 
outreg2 *ExcResvDepositRatio *EquityRatio using Table4.xls, nocons bde(2) append

* column (3) fed member with fixed effects
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio  *lagCollaLoanRatio ///
if DIDok&bank_age>5 & year>1928 & fed, cl(id) fe 
outreg2 *ExcResvDepositRatio *EquityRatio  using Table4.xls, nocons bde(2) append

* column (4) non-member with fixed effects
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & !fed, cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio  using Table4.xls, nocons bde(2) append

// core vs periphery

* column (5) core banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & (CorrespondentBusiness==1), cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio *CollaLoanRatio using Table4.xls, nocons bde(2) append

* column (6) periphery banks
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & (missing(CorrespondentBusiness)), cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio *CollaLoanRatio using Table4.xls, nocons bde(2) append


// security affiliate vs no affiliate

* column (7) security affiliate
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & (CorrespondentBusiness==1), cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio *CollaLoanRatio using Table4.xls, nocons bde(2) append

* column (8) no affiliate
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & (missing(CorrespondentBusiness)), cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio *CollaLoanRatio using Table4.xls, nocons bde(2) append


// Foreign Deposits 
// excess reserve ratio, capital ratio, unsecured to all loans(as control)

* column (9) substantial foreign exposure
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & positiveForeign==1, cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio  using Table4.xls, nocons bde(2) append

* column (10) little foreign exposure
xtreg PreUnpreGrowth _* *lagExcResvDepositRatio *lagEquityRatio *lagCollaLoanRatio  ///
if DIDok&bank_age>5 & year>1928 & positiveForeign!=1, cl(id) fe
outreg2 *ExcResvDepositRatio  *EquityRatio  using Table4.xls, nocons bde(2) append


***********************************************************************************
* Table 5: Interest rates paid to depositors in northern New Jersey, 1929 to 1938 *
***********************************************************************************

import excel using "..\@JMCB accept\NJ_deposit_rate_final.xls" ///
, sheet("Sheet1") firstrow case(lower) clear

gen di=(year>1932)

sum maximumrateofinterestondep if di==0
sum maximumrateofinterestondep if di==1

ttest maximumrateofinterestondep, by(di) unequal
